@@ -53,7 +53,7 @@ class Execution(
             def stub(
                 scope: ros_cdk_core.Construct,
                 id: builtins.str,
-                props: typing.Union["ExecutionProps", typing.Dict[str, typing.Any]],
+                props: typing.Union[ExecutionProps, typing.Dict[str, typing.Any]],
                 enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
             ) -> None:
                 ...
@@ -175,7 +175,7 @@ class ExecutionProps:
                 parameters: typing.Optional[typing.Union[ros_cdk_core.IResolvable, typing.Mapping[builtins.str, typing.Any]]] = None,
                 parent_execution_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
                 resource_group_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
-                resource_options: typing.Optional[typing.Union[ros_cdk_core.IResolvable, typing.Union["RosExecution.ResourceOptionsProperty", typing.Dict[str, typing.Any]]]] = None,
+                resource_options: typing.Optional[typing.Union[ros_cdk_core.IResolvable, typing.Union[RosExecution.ResourceOptionsProperty, typing.Dict[str, typing.Any]]]] = None,
                 safety_check: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
                 tags: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
                 template_version: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
@@ -333,7 +333,7 @@ class Parameter(
             def stub(
                 scope: ros_cdk_core.Construct,
                 id: builtins.str,
-                props: typing.Union["ParameterProps", typing.Dict[str, typing.Any]],
+                props: typing.Union[ParameterProps, typing.Dict[str, typing.Any]],
                 enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
             ) -> None:
                 ...
@@ -521,7 +521,7 @@ class RosExecution(
             def stub(
                 scope: ros_cdk_core.Construct,
                 id: builtins.str,
-                props: typing.Union["RosExecutionProps", typing.Dict[str, typing.Any]],
+                props: typing.Union[RosExecutionProps, typing.Dict[str, typing.Any]],
                 enable_resource_property_constraint: builtins.bool,
             ) -> None:
                 ...
@@ -784,7 +784,7 @@ class RosExecution(
     ) -> None:
         if __debug__:
             def stub(
-                value: typing.Optional[typing.Union[ros_cdk_core.IResolvable, "RosExecution.ResourceOptionsProperty"]],
+                value: typing.Optional[typing.Union[ros_cdk_core.IResolvable, RosExecution.ResourceOptionsProperty]],
             ) -> None:
                 ...
             type_hints = typing.get_type_hints(stub)
@@ -1192,7 +1192,7 @@ class RosParameter(
             def stub(
                 scope: ros_cdk_core.Construct,
                 id: builtins.str,
-                props: typing.Union["RosParameterProps", typing.Dict[str, typing.Any]],
+                props: typing.Union[RosParameterProps, typing.Dict[str, typing.Any]],
                 enable_resource_property_constraint: builtins.bool,
             ) -> None:
                 ...
@@ -1588,7 +1588,7 @@ class RosTemplate(
             def stub(
                 scope: ros_cdk_core.Construct,
                 id: builtins.str,
-                props: typing.Union["RosTemplateProps", typing.Dict[str, typing.Any]],
+                props: typing.Union[RosTemplateProps, typing.Dict[str, typing.Any]],
                 enable_resource_property_constraint: builtins.bool,
             ) -> None:
                 ...
@@ -1880,7 +1880,7 @@ class Template(
             def stub(
                 scope: ros_cdk_core.Construct,
                 id: builtins.str,
-                props: typing.Union["TemplateProps", typing.Dict[str, typing.Any]],
+                props: typing.Union[TemplateProps, typing.Dict[str, typing.Any]],
                 enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
             ) -> None:
                 ...
